# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added
- Initial project setup
- Basic remote policy checking functionality
- HTTP-based policy enforcement
- Sample policy files and examples
- Basic test suite

### Changed
- None

### Deprecated
- None

### Removed
- None

### Fixed
- None

### Security
- None 